OC.L10N.register(
    "core",
    {
    "Please select a file." : "Izberite datoteko.",
    "File is too big" : "Datoteka je prevelika",
    "The selected file is not an image." : "Izbrana datoteka ni slika.",
    "The selected file cannot be read." : "Izbrane datoteke ni mogoče prebrati.",
    "The file was uploaded" : "Datoteka je bila poslana.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega največjo dovoljeno velikosti, kot je zabeležena v datoteki php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
    "No file was uploaded" : "Nobena datoteka ni bila poslana.",
    "Missing a temporary folder" : "Začasna mapa ni na voljo",
    "Could not write file to disk" : "Datoteke ni mogoče zapisati na disk",
    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
    "Invalid file provided" : "Predložena je neveljavna datoteka",
    "No image or file provided" : "Ni podane datoteke ali slike",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
    "Invalid image" : "Neveljavna slika",
    "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
    "No crop data provided" : "Ni podanih podatkov obreza",
    "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
    "Crop is not square" : "Obrez ni pravokoten",
    "State token does not match" : "Žeton stanja ni skladen",
    "Invalid app password" : "Neveljavno geslo programa",
    "Could not complete login" : "Prijave ni mogoče dokončati",
    "Your login token is invalid or has expired" : "Prijavni žeton je neveljaven, ali pa je že potekel.",
    "Login" : "Prijava",
    "Password reset is disabled" : "Ponastavitev gesla je onemogočena",
    "Could not reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton pretekel.",
    "Could not reset password because the token is invalid" : "Ni mogoče ponastaviti gesla, ker žeton ni veljaven.",
    "%s password reset" : "Ponastavitev gesla %s",
    "Password reset" : "Ponastavitev gesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Za ponastavitev gesla kliknite na gumb. Če ponastavitve gesla niste zahtevali, prezrite to sporočilo.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Za ponastavitev gesla kliknite na povezavo. Če ponastavitve gesla niste zahtevali, prezrite to sporočilo.",
    "Reset your password" : "Ponastavi geslo",
    "Nextcloud Server" : "Strežnik Nextcloud",
    "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
    "The user limit of this instance is reached." : "Dosežena je količinska omejitev za uporabnika.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Vpišite ključ naročnine in povečajte omejitev za uporabnika. Za več podrobnosti si oglejte Poslovni paket Nextcloud na spletni strani.",
    "Preparing update" : "Poteka priprava na posodobitev ...",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Korak nadgradnje:",
    "Repair info:" : "Podrobnosti nadgradnje:",
    "Repair warning:" : "Opozorilo nadgradnje:",
    "Repair error:" : "Napaka nadgradnje:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Posodobitev sistema je treba izvesti v ukazni vrstici, ker je nastavitev samodejne posodobitve v config.php onemogočena.",
    "Turned on maintenance mode" : "Vzdrževalni način je omogočen ...",
    "Turned off maintenance mode" : "Vzdrževalni način je onemogočen.",
    "Maintenance mode is kept active" : "Vzdrževalni način ostane dejaven.",
    "Updating database schema" : "Poteka posodabljanje sheme podatkovne zbirke ...",
    "Updated database" : "Podatkovna zbirka je posodobljena.",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
    "Updated \"%1$s\" to %2$s" : "Posodabljanje »%1$s« na različico %2$s",
    "Set log level to debug" : "Nastavljanje ravni beleženja za razhroščevanje",
    "Reset log level" : "Ponastavljanje ravni beleženja",
    "Starting code integrity check" : "Poteka preverjanje stanja kode ...",
    "Finished code integrity check" : "Preverjanje stanja kode je končano.",
    "%s (incompatible)" : "%s (neskladno)",
    "The following apps have been disabled: %s" : "Zaradi neskladnosti so onemogočeni naslednji programi: %s.",
    "Already up to date" : "Sistem je že posodobljen",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je vmesnik WebDAV videti okvarjen.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Spletni strežnik ni ustrezno nastavljen za razreševanje naslova URL »{url}«. Več podrobnosti je zapisanih v {linkstart}dokumentaciji ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Spletni strežnik ni ustrezno nastavljen za razreševanje naslova URL »{url}«. Napaka je najverjetneje povezana z nastavitvami, ki niso bile posodobljene za neposreden dostop do te mape. Primerjajte nastavitve s privzeto različico pravil ».htaccess« za strežnik Apache, ali pa zapis za Nginx, ki je opisan v {linkstart}dokumentaciji ↗{linkend}. Na strežniku Nginx je običajno treba posodobiti vrstice, ki se začnejo z »location ~«.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Spletni strežnik ni ustrezno nastavljen za obdelavo datotek .wolff2. Običajno je težava v nastavitvah Nginx. Različica Nextcloud 15 zahteva posebno prilagoditev. Primerjajte nastavitve s priporočenimi, kot je to zabeleženo v {linkstart}dokumentaciji ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Kaže, da okolje PHP ni ustrezno nastavljeno za poizvedovanje sistemskih spremenljivk. Preizkus z ukazom getegetenv(\"PATH\") vrne le prazen odziv.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Preverite {linkstart}namestitveno dokumentacijo ↗{linkend} za nastavitve PHP strežnika, še posebej, če uporabljate php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Nastavitve so nastavljene le za branje. To onemogoča prilagajanje prek spletnega vmesnika, prav tako je treba nastavitveno datoteko  vsakič znova ročno posodobiti.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Podatkovna zbirka ni zagnana na ravni »READ COMMITTED«. To lahko povzroči težave pri vzporednem izvajanju dejanj.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Manjka modul PHP »fileinfo«. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Zaklepanje datotek je onemogočeno, kar lahko privede do različnih težav. V izogib zapletom je priporočljivo omogočiti možnost »filelocking.enabled« v datoteki config.php. Več podrobnosti je zapisanih v {linkstart}dokumentaciji ↗{linkend}.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Med nastavitvami namestitve ni določenega privzetega telefonskega področja. To je pomembno za overjanje telefonskih številk brez uporabe kode države. Za vpis številk brez kode je treba dodati možnost »default_phone_region« z ustrezno kodo regije po določilih {linkstart}ISO 3166-1 ↗{linkend}.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ni mogoče izvesti opravila cron prek vmesnika ukazne vrstice. Pojavile so se tehnične napake:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Zadnje ozadnje izvajanje opravila je potekalo {relativeTime}. Kaže, da je nekaj narobe. {linkstart}Preverite nastavitve ozadnjih programov ↗{linkend}",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ni nastavljenega predpomnilnika. Za izboljšanje hitrosti delovanja je treba predpomnilnik memcache, če je na voljo, ustrezno nastaviti. Več podrobnosti je na voljo v {linkstart}dokumentaciji ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Iz varnostnih razlogov je priporočljivo nastaviti ustrezen vir za naključno ustvarjanje podatkov, ki ga uporablja PHP. Več podrobnosti je zapisanih v {linkstart}dokumentaciji ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Trenutno je zagnana različica PHP {version}. Priporočljivo je posodobiti sistem na najnovejšo različico in s tem namestiti {linkstart}funkcijske in varnostne posodobitve delovanja, ki jih zagotavlja Skupina PHP ↗{linkend}. Pakete je priporočljivo posodobiti takoj, ko so na voljo za nameščeno distribucijo.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nastavitev povratne posredovalniške glave ni pravilna ali pa v okolje Nextcloud dostopate prek zaupanja vrednega strežnika. Če slednje ne drži, je to varnostno tveganje, ki lahko omogoči tretji osebi dostop do okolja. Več podrobnosti je na voljo v {linkstart}dokumentaciji ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Predpomnilnik memcached je nastavljen kot porazdeljen predpomnilnik, vendar pa je nameščen napačen modul PHP »memcache«. Modul \\OC\\Memcache\\Memcached podpira le »memcached«, ne pa tudi »memcache«. Več podrobnosti za oba modula je zapisanih na {linkstart}straneh wiki ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Nekatere datoteke ne opravijo preizkusa celovitosti. Več podrobnosti o težavi je opisanih v {linkstart1}dokumentaciji ↗{linkend} ({linkstart2}Seznam neveljavnih datotek …{linkend} / {linkstart3}Ponovni preizkus … {linkend}).",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP »set_time_limit« ni na voljo. To lahko povzroči nepričakovano zaustavitev skriptnih ukazov med izvajanjem, kar lahko povzroči sesutje namestitve. To možnost je priporočeno omogočiti.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Namestitev PHP je brez ustrezne podpore za FreeType, kar pogosto vpliva na težave s slikami profila in nastavitvami vmesnika.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Manjka kazalo » {indexName} « v razpredelnici »{tableName}«.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V podatkovni zbirki ni določenih nekaterih določil. Ker je dodajanje določil na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno. Z ukazom »occ db: add-missing-indices« je določila mogoče varno dodati ročno, medtem ko je sistem v delovanju. Po dodajanju bo izvajanje poizvedb teh razpredelnic neprimerno hitrejše.",
    "Missing primary key on table \"{tableName}\"." : "Manjka osnovni ključ v razpredelnici »{tableName}«.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "V podatkovni zbirki ni določenih nekaterih osnovnih ključev. Ker je dodajanje ključev na velikih razpredelnicah časovno izredno zahtevno opravilo, ti niso dodani samodejno. Z ukazom »occ db:add-missing-primary-keys« je ključe mogoče varno dodati ročno, medtem ko je sistem v delovanju.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Manjka izbirni stolpec »{columnName}« v razpredelnici »{tableName}«.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V podatkovni zbirki manjka nekaj izbirnih stolpcev. Ker je dodajanje stolpcev na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno, ker so v osnovi izbirna. Z ukazom »occ db:add-missing-columns« je stolpce mogoče varno dodati ročno med delovanjem sistema. Po dodajanju bo odzivnost in uporabnost nekaterih zmožnosti občutna izboljšana.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Namestitev PHP ne vključuje nekaterih priporočenih modulov. Za izboljšanje delovanja in boljšo skladnost jih je zelo priporočljivo omogočiti.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick ne vključuje podpore za SVG. Za izboljšanje delovanja in boljšo skladnost jih je zelo priporočljivo omogočiti.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Trenutno je uporabljena ozadnja podatkovna zbirka SQLite. Za obsežnejše sisteme je priporočljiv prehod na drugo vrsto zbirke.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Priporočilo ima še večjo težo, če se sistem krajevno usklajuje z namizjem prek odjemalca.",
    "The PHP memory limit is below the recommended value of 512MB." : "Omejitev pomnilnika PHP je pod priporočljivo vrednostjo 512 MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Nekatere mape programov imajo lastništvo določeno na uporabnika ni ni spletni strežniški uporabnik. To se lahko zgodi, če so programi nameščeni ročno. Preveriti je treba dovoljenja map:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Podatkovna zbirka MySQL je v uporabi, ni pa omogočena podpora za 4-bitne znake. Za uporabo teh znakov (kot so na primer grafične izrazne ikone) brez težav tudi v imenih datotek in opombah, je priporočljivo podporo omogočiti med nastavitvami MySQL. Več podrobnosti je zabeleženih v {linkstart}dokumentaciji ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Program uporablja shrambo predmetov S3 kot osnovno shrambo. Naložene datoteke se začasno shranjujejo na strežniku, zato je priporočljivo omogočiti 50 GB začasnega pomnilnika PHP. Podrobnosti o poti in razpoložljivem prostoru so zapisane v dnevniku. Za izboljšanje delovanja je treba spremeniti podatke začasnega imenika v php.ini ali omogočiti več prostora na trenutno določenem mestu. ",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Dostop do okolja poteka prek varne povezave, a ta ustvarja ne-varne naslove URL. To najverjetneje pomeni, da je strežnik za povratnim strežnikom in da spremenljivke nastavitev niso pravilno nastavljene. Več o tem je zabeleženo v {linkstart}dokumentaciji ↗{linkend}.",
    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava HTTP »{header}« ni nastavljena na pričakovano vrednost »{expected}«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Glava HTTP »{header}« ni nastavljena na pričakovano vrednost »{expected}«. Nekatere možnosti morda ne bodo delovale pravilno, zato je priporočljivo prilagoditi nastavitve.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava \"{header}\" HTTP ne vsebuje »{expected}«. To je potencialno varnostna luknja, zato priporočamo prilagoditev nastavitev.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Glava HTTP »{header}« ni nastavljena na »{val1}«, »{val2}«, »{val3}«, »{val4}« oziroma »{val5}«. To lahko povzroči iztekanje podatkov sklicatelja. Več o tem si lahko ogledate med priporočili {linkstart}priporočili W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Glava HTTP za varen prenos podatkov »Strict-Transport-Security« ni nastavljena na vsaj »{seconds}« sekund. Za večjo varnost je priporočljivo omogočiti pravila HSTS, kot je opisano med {linkstart}varnostnimi priporočili ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Dostop do strani je omogočen pred nevarovanega protokola HTTP. Priporočljivo je na strežniku vsiliti uporabo HTTPS, kot je zavedeno med {linkstart}varnostnimi priporočili ↗{linkend}.",
    "unknown text" : "neznano besedilo",
    "Hello world!" : "Pozdravljen svet!",
    "sunny" : "sončno",
    "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
    "Hello {name}" : "Pozdravljeni, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To so zadetki iskanja<script>alert(1)</script></strong>.",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "V teku je posodobitev. Odhod s te strani lahko v določenih okoljih prekine opravilo.",
    "Update to {version}" : "Posodobitev na različico {version}",
    "An error occurred." : "Prišlo je do napake.",
    "Please reload the page." : "Stran je treba osvežiti.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
    "Continue to {productName}" : "Nadaljuj v {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundo.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundi.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekunde.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekund."],
    "More apps" : "Več programov",
    "Log in" : "Prijava",
    "Logging in …" : "Poteka prijavljanje ...",
    "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
    "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
    "An internal error occurred." : "Prišlo je do notranje napake.",
    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
    "Password" : "Geslo",
    "Wrong username or password." : "Napačno uporabniško ime oziroma geslo",
    "User disabled" : "Uporabnik je onemogočen",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
    "Username or email" : "Uporabniško ime ali elektronski naslov",
    "Your account is not setup for passwordless login." : "Račun ni nastavljen za brezgeselno prijavo.",
    "Browser not supported" : "Trenutno uporabljen brskalnik ni podprt!",
    "Passwordless authentication is not supported in your browser." : "Brezgeselna overitev v tem brskalniku ni podprta.",
    "Your connection is not secure" : "Vzpostavljena povezava ni varna",
    "Passwordless authentication is only available over a secure connection." : "Brezgeselna overitev je na voljo le prek vzpostavljene varne povezave.",
    "Reset password" : "Ponastavi geslo",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Sporočilo za ponastavitev gesla je bilo poslano na elektronski naslov računa. Če sporočila v kratkem ne prejmete, preverite mape neželene pošte ali pa za pomoč prosite krajevnega skrbnika sistema.",
    "If it is not there ask your local administrator." : "Če sporočila ni, stopite v stik s skrbnikom sistema.",
    "Couldn't send reset email. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev. Stopite v stik s skrbnikom sistema.",
    "Password cannot be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
    "Back to login" : "Nazaj na prijavo",
    "New password" : "Novo geslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Datoteke so šifrirane. Če niste omogočili obnovitvenega ključa, po ponastavitvi gesla dostop do datotek ne bo več mogoč.<br />Če niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali res želite nadaljevati?",
    "I know what I'm doing" : "Vem, kaj delam!",
    "Resetting password" : "Ponastavljanje gesla",
    "Recommended apps" : "Priporočeni programi",
    "Loading apps …" : "Poteka nalaganje programov ...",
    "Installing apps …" : "Poteka nameščanje programov ...",
    "App download or installation failed" : "Prejem oziroma namestitev programa je spodletela.",
    "Cannot install this app because it is not compatible" : "Programa ni mogoče namestiti, ker ni skladen z različico okolja.",
    "Cannot install this app" : "Programa ni mogoče namestiti.",
    "Skip" : "Preskoči",
    "Install recommended apps" : "Namesti priporočene programe",
    "Schedule work & meetings, synced with all your devices." : "Načrtujte delo in sestanke, ki se samodejno usklajujejo z vsemi vašimi napravami.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Združite sodelavce in prijatelje na enem mestu brez skrbi za njihove zasebne podatke.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enostaven program za pošto se odlično povezuje z Datotekami, Stiki in Koledarjem.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, video klici, souporaba zaslonske slike, spletni sestanki in konference – znotraj brskalnika in z mobilnimi napravami.",
    "Collaboratively edit office documents." : "Sodelovalno urejanje pisarniških dokumentov.",
    "Local document editing back-end used by the Collabora Online app." : "Ozadnji program za krajevno urejanje dokumentov, ki ga uporablja program Collabora Online.",
    "Forgot password?" : "Ali ste pozabili geslo?",
    "Log in with a device" : "Prijava z napravo",
    "Back" : "Nazaj",
    "Login form is disabled." : "Prijavni obrazec je onemogočen.",
    "Edit Profile" : "Uredi profil",
    "Reset search" : "Ponastavi iskanje",
    "Search for {name} only" : "Išči le za {name}",
    "No results for {query}" : "Ni zadetkov za poizvedbo {query}",
    "Start typing to search" : "Začnite tipkati za iskanje",
    "Loading more results …" : "Poteka nalaganje več zadetkov ...",
    "Load more results" : "Naloži več zadetkov",
    "Search" : "Poišči",
    "An error occurred while searching for {type}" : "Prišlo je do napake med iskanjem vrste {type}.",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Vpisati je treba vsaj {minSearchLength} znak za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znaka za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znake za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znakov za začetek iskanja"],
    "Search {types} …" : "Poišči {types} …",
    "Settings" : "Nastavitve",
    "Could not load your contacts" : "Stikov ni mogoče naložiti",
    "Search contacts …" : "Poišči med stiki ...",
    "No contacts found" : "Ni najdenih stikov",
    "Show all contacts …" : "Prikaži vse stike ...",
    "Install the Contacts app" : "Namesti program Stiki",
    "Loading your contacts …" : "Poteka nalaganje stikov ...",
    "Looking for {term} …" : "Poteka iskanje {term} …",
    "No" : "Ne",
    "Yes" : "Da",
    "No files in here" : "Na tem mestu še ni datotek",
    "New folder" : "Nova mapa",
    "No more subfolders in here" : "V mapi ni več podrejenih map",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
    "{newName} already exists" : "{newName} že obstaja",
    "Choose" : "Izbor",
    "Copy" : "Kopiraj",
    "Move" : "Premakni",
    "Error loading file picker template: {error}" : "Napaka nalaganja predloge izbirnika datotek: {error}",
    "OK" : "V redu",
    "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
    "read-only" : "le za branje",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"],
    "One file conflict" : "En spor datotek",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Obstoječe datoteke",
    "Which files do you want to keep?" : "Katere datoteke želite ohraniti?",
    "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu kopirane datoteke dodana številka.",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "(all selected)" : "(vse izbrano)",
    "({count} selected)" : "({count} izbranih)",
    "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
    "Show list view" : "Pokaži seznamski pogled",
    "Show grid view" : "Pokaži mrežni pogled",
    "Pending" : "Na čakanju",
    "Copy to {folder}" : "Kopiraj v {folder}",
    "Move to {folder}" : "Premakni v {folder}",
    "Saving …" : "Poteka shranjevanje ...",
    "Authentication required" : "Opravilo zahteva overitev!",
    "This action requires you to confirm your password" : "Opravilo zahteva potrditev z vpisom skrbniškega gesla.",
    "Confirm" : "Potrdi",
    "Failed to authenticate, try again" : "Med overjanjem je prišlo do napake, poskusite znova.",
    "seconds ago" : "pred nekaj sekundami",
    "Connection to server lost" : "Povezava s strežnikom je izgubljena",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundo.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundi.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekunde.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekund."],
    "Add to a project" : "Dodaj k projektu",
    "Show details" : "Pokaži podrobnosti",
    "Hide details" : "Skrij podrobnosti",
    "Rename project" : "Preimenuj projekt",
    "Failed to rename the project" : "Preimenovanje projekta je spodletelo.",
    "Failed to create a project" : "Ustvarjanje projekta je spodletelo",
    "Failed to add the item to the project" : "Dodajanje predmeta k projektu je spodletelo.",
    "Connect items to a project to make them easier to find" : "Povežite predmete s projektom, da jih bo lažje najti.",
    "Type to search for existing projects" : "Vpišite niz za iskanje obstoječih projektov",
    "New in" : "Novo v",
    "View changelog" : "Poglej dnevnik sprememb",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "No action available" : "Ni razpoložljivih dejanj",
    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
    "restricted" : "omejeno",
    "invisible" : "nevidno",
    "Delete" : "Izbriši",
    "Rename" : "Preimenuj",
    "Collaborative tags" : "Sodelovalne oznake",
    "No tags found" : "Ni najdenih oznak",
    "Personal" : "Osebno",
    "Users" : "Uporabniki",
    "Apps" : "Programi",
    "Admin" : "Skrbništvo",
    "Help" : "Pomoč",
    "Access forbidden" : "Dostop je prepovedan",
    "Profile not found" : "Profila ni mogoče najti",
    "The profile does not exist." : "Profil ne obstaja.",
    "Back to %s" : "Nazaj na %s",
    "File not found" : "Datoteke ni mogoče najti",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Na strežniku ni mogoče najti dokumentacije. Morda je mesto souporabe izbrisano, ali pa so potekla dovoljenja.",
    "Too many requests" : "Zaznanih je preveč sočasnih zahtev",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iz omrežja je bilo prejetih preveč zahtev. Če je to napaka, stopite v stik s skrbnikom, sicer pa poskusite spet kasneje.",
    "Error" : "Napaka",
    "Previous" : "Nazaj",
    "Internal Server Error" : "Notranja napaka strežnika",
    "The server was unable to complete your request." : "Odziv strežnika kaže, da zahteve ni mogoče dokončati.",
    "If this happens again, please send the technical details below to the server administrator." : "Če se napaka ponovi, pošljite tehnične podrobnosti, ki so zbrane spodaj, skrbniku sistema.",
    "More details can be found in the server log." : "Več podrobnosti je zabeleženih v dnevniški datoteki strežnika.",
    "Technical details" : "Tehnične podrobnosti",
    "Remote Address: %s" : "Oddaljen naslov: %s",
    "Request ID: %s" : "ID zahteve: %s",
    "Type: %s" : "Vrsta: %s",
    "Code: %s" : "Koda: %s",
    "Message: %s" : "Sporočilo: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Vrstica: %s",
    "Trace" : "Sledenje povezav",
    "Security warning" : "Varnostno opozorilo",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Več podrobnosti, kako pravilno nastaviti strežnik, je zapisanih v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
    "Create an <strong>admin account</strong>" : "Ustvari <strong>skrbniški račun</strong>",
    "Username" : "Uporabniško ime",
    "Show password" : "Pokaži geslo",
    "Toggle password visibility" : "Preklopi vidnost gesla",
    "Storage & database" : "Shramba in podatkovna zbirka",
    "Data folder" : "Podatkovna mapa",
    "Configure the database" : "Nastavi podatkovno zbirko",
    "Only %s is available." : "Na voljo je le %s.",
    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
    "Database user" : "Uporabnik podatkovne zbirke",
    "Database password" : "Geslo podatkovne zbirke",
    "Database name" : "Ime podatkovne zbirke",
    "Database tablespace" : "Razpredelnica podatkovne zbirke",
    "Database host" : "Gostitelj podatkovne zbirke",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
    "Performance warning" : "Opozorilo učinkovitosti delovanja",
    "You chose SQLite as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Podatkovna zbirka SQLite je primerna le za manjše in razvojne namestitve. Za produkcijsko okolje je priporočljivo uporabiti drugo podatkovno ozadje.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Če uporabljate namizni odjemalec za usklajevanje datotek, je uporaba podatkovne zbirke SQLite odsvetovana.",
    "Install" : "Namesti",
    "Need help?" : "Ali potrebujete pomoč?",
    "See the documentation" : "Preverite dokumentacijo",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Kaže, da poskušate ponovno namestiti okolje Nextcloud, a datoteke CAN_INSTALL ni v mapi nastavitev. Ustvarite jo, potem lahko poskusite znova.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ni mogoče odstraniti datoteke CAN_INSTALL iz nastavitvene mape. Odstranite jo ročno.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
    "Skip to main content" : "Preskoči na glavno vsebino",
    "Skip to navigation of app" : "Preskoči na program za krmarjenje",
    "Get your own free account" : "Pridobite brezplačni račun",
    "Contacts" : "Stiki",
    "Contacts menu" : "Meni Stikov",
    "Confirm your password" : "Potrdite geslo",
    "Connect to your account" : "Povežite z računom",
    "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Če ne poskušate dodati naprave ali programa, vas poskuša nekdo pretentati v odobritev dostopa do vaših podatkov. Če se vam zdi, da je tako, ne nadaljujte s potrjevanjem, ampak stopite v stik s skrbnikom sistema.",
    "App token" : "Žeton programa",
    "Grant access" : "Odobri dostop",
    "Alternative log in using app token" : "Alternativni način prijave z uporabo programskega žetona",
    "Account access" : "Dostop do računa",
    "You are about to grant %1$s access to your %2$s account." : "Računu %1$s boste omogočili dostop do vašega računa %2$s.",
    "Account connected" : "Račun je povezan",
    "Your client should now be connected!" : "Odjemalec naj bi bil sedaj povezan!",
    "You can close this window." : "To okno lahko zaprete.",
    "This share is password-protected" : "To mesto je zaščiteno z geslom",
    "Email address" : "Elektronski naslov",
    "Go to %s" : "Odpri oblak %s",
    "Two-factor authentication" : "Dvo-stopenjska overitev",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Za vaš račun je omogočena zahteva za višjo raven varnosti. Izberite drugo stopnjo overitve:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ni mogoče naložiti niti enega od omogočenih načinov dvostopenjske overitve prijave. Stopite v stik s skrbnikom sistema.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Zahtevana je uporaba dvostopenjske overitve prijave, a za ta račun še ni nastavljena. Stopite v stik s skrbnikom sistema.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Zahtevana je uporaba dvostopenjske overitve prijave, a za ta račun še ni nastavljena. Nadaljujte s postopkom priprave overitve.",
    "Set up two-factor authentication" : "Nastavitev dvostopenjske overitve",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Zahtevana je uporaba dvostopenjske overitve prijave, a za ta račun še ni nastavljena. Za prijavo uporabite eno izmed varnostnih kod, ali pa za pomoč stopite v stik s skrbnikom sistema.",
    "Use backup code" : "Uporabi varnostno kopijo šifre",
    "Cancel login" : "Prekliči prijavo",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Za vaš račun je vsiljena zahteva za višjo raven varnosti. Izberite ponudnika za nastavitev:",
    "Error while validating your second factor" : "Napaka med preverjanjem drugega koraka",
    "Access through untrusted domain" : "Dostop z uporabo domene, ki ni zaupanja vredna",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Stopite v stik s skrbnikom sistema. Če ste skrbnik, prilagodite nastavitev »trusted_domains« v datoteki config/config.php, kot je zavedeno v predlogi config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Podrobnosti o možnostih nastavitev je mogoče najti v %1$sdokumentaciji%2$s.",
    "App update required" : "Zahtevana je posodobitev programa",
    "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
    "The following apps will be updated:" : "Navedeni programi bodo posodobljeni:",
    "These incompatible apps will be disabled:" : "Zaradi neskladnosti bodo onemogočeni:",
    "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
    "Start update" : "Začni posodobitev",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
    "Detailed logs" : "Podrobni dnevniški zapisi",
    "Update needed" : "Zahtevana je posodobitev",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Uporabite posodabljalnik ukazne vrstice, ker je v sistemu več kot 50 uporabnikov.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Za pomoč si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacijo</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Zavedam se, da obstaja pri posodabljanju prek spletnega uporabniškega vmesnika nevarnost, da zahteva časovno poteče in s tem povzroči izgubo podatkov. Imam ustvarjeno varnostno kopijo in znam podatke iz kopij v primeru napak obnoviti.",
    "Upgrade via web on my own risk" : "Posodobi prek spleta kljub večjemu tveganju",
    "Maintenance mode" : "Vzdrževalni način",
    "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
    "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Če se bo to sporočilo še naprej nepričakovano pojavljalo, stopite v stik s skrbnikom sistema.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Poteka preverjanje razpredelnice %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Strežnik je brez vzpostavljene internetne povezave. Več končnih točk ni mogoče doseči. To pomeni, da priklapljanje zunanjih diskov,  opozorila za posodobitve in namestitve programske opreme iz drugih virov, niso mogoče. Oddaljen dostop do datotek in pošiljanje obvesti najverjetneje prav tako ne deluje. Vzpostavite povezavo, da omogočite vso funkcionalnost.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Okolje Nextcloud 20 je zadnja različica, ki omogoča podporo PHP 7.2. Nextcloud 21 zahteva vsaj različico PHP 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Modul PHP OPcache ni naložen. {linkstart}Za najboljše delovanje je priporočljivo ↗{linkend} modul dodati k uporabljeni namestitvi PHP.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Modul PHP OPcache ni pravilno nastavljen. {linkstart}Za najboljše delovanje je priporočljivo ↗{linkend} uporabiti posebne nastavitve v datoteki <code>php.ini</code>:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Nekateri stolpci v podatkovni zbirki so brez pretvornika velikih števil. Ker je spreminjanje stolpcev na velikih razpredelnicah časovno izredno zahtevno opravilo, ti niso spremenjeni samodejno. Z ukazom »occ db:convert-filecache-bigint« je mogoče te spremembe dodati ročno. Opravilo je treba izvesti, ko okolje ni dejavno. Več podrobnosti je zabeleženih v {linkstart}dokumentaciji ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Za prehod sistema na drugo podatkovno zbirko, uporabite ukaz orodne vrstice: »occ db:convert-type«, več o tem pa je zapisano v {linkstart}dokumentaciji ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Podatkovna mapa in datoteke so najverjetneje dostopni na Internetu, ker datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da dostop do mape z zunanjega omrežja ni mogoč, ali pa tako, da podatkovno mapo prestavite izven korenske mape strežnika.",
    "More" : "Več",
    "More apps menu" : "Meni več programov",
    "Settings menu" : "Meni nastavitev",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Setup two-factor authentication" : "Nastavite dvostopenjsko overitev"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
